pitchtools.ChromaticPitchObject
===============================

.. inheritance-diagram:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__abs__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__eq__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__float__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__ge__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__gt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__hash__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__int__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__le__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__lt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__ne__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__repr__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.ChromaticPitchObject.ChromaticPitchObject.ChromaticPitchObject.__str__

    Inherited from `__builtin__.object`
